@@ -18,7 +18,7 @@ use Exception::Class (
 );
 use Minions::_Guts;
 
-our $VERSION = '0.000006';
+our $VERSION = '0.000007';
 $VERSION = eval $VERSION;
 
 my $Class_count = 0;
@@ -300,9 +300,9 @@ sub _get_object_maker {
         my $stash = Package::Stash->new($class);
 
         my $spec = $stash->get_symbol('%__meta__');
-        my $obfu_pkg = Minions::_Guts::obfu_name('', $spec);
+        my $pkg_key = Minions::_Guts::obfu_name('', $spec);
         my %obj = (
-            $obfu_pkg => ${ $stash->get_symbol('$__Private_pkg') },
+            $pkg_key => ${ $stash->get_symbol('$__Private_pkg') },
         );
 
         while ( my ($attr, $meta) = each %{ $spec->{implementation}{has} } ) {
@@ -497,6 +497,7 @@ sub _add_methods {
         }
         return UNIVERSAL::can($self, $f);
     };
+    _add_autoload($spec, $stash);
 
     while ( my ($name, $meta) = each %{ $spec->{implementation}{has} } ) {
 
@@ -513,7 +514,7 @@ sub _add_methods {
              && $meta->{writer}
              && $in_interface->{$name} ) {
 
-            my $name = $meta->{writer} == 1 ? "change_$name" : $meta->{writer};
+            my $name = $meta->{writer};
             my $obfu_pkg = Minions::_Guts::obfu_name('', $spec);
             $spec->{implementation}{methods}{$name} = sub {
                 my ($self, $new_val) = @_;
@@ -535,6 +536,33 @@ sub _add_methods {
     }
 }
 
+sub _add_autoload {
+    my ($spec, $stash) = @_;
+
+    $spec->{implementation}{methods}{AUTOLOAD} = sub {
+        my $self = shift;
+
+        my $caller_sub = (caller 1)[3];
+        my $caller_pkg = $caller_sub;
+        $caller_pkg =~ s/::[^:]+$//;
+
+        my $called = ${ $stash->get_symbol('$AUTOLOAD') };
+        $called =~ s/.+:://;
+
+        if(    exists $spec->{implementation}{semiprivate}{$called}
+            && $caller_pkg eq ref $self
+        ) {
+            my $stash = _get_stash($spec->{implementation}{package});
+            my $sp_var = ${ $stash->get_symbol('$__') };
+            return $self->{$sp_var}->$called($self, @_);
+        }
+        else {
+            croak sprintf(q{Can't locate object method "%s" via package "%s"},
+                          $called, ref $self);
+        }
+    };
+}
+
 sub _add_delegates {
     my ($spec, $meta, $name) = @_;
 
@@ -574,7 +602,7 @@ sub _interface {
 
     $type ||= 'interface';
     my %must_allow = (
-        interface   => [qw( can DOES DESTROY )],
+        interface   => [qw( AUTOLOAD can DOES DESTROY )],
         semiprivate => [qw( BUILD )],
     );
     return { map { $_ => 1 } @{ $spec->{$type} }, @{ $must_allow{$type} } };
@@ -587,7 +615,7 @@ __END__
 
 =head1 NAME
 
-Minions - What is I<your> API?
+Minions - Simplifies the creation of loosely coupled object oriented code.
 
 =head1 SYNOPSIS
 
@@ -645,10 +673,10 @@ This is an early release available for testing and feedback and as such is subje
 =head1 DESCRIPTION
 
 Minions is a class builder that makes it easy to create classes that are L<modular|http://en.wikipedia.org/wiki/Modular_programming>, which means
-there is a clear separation between what end users need to know (the interface for using the class) and implementation details that users
+there is a clear and obvious separation between what end users need to know (the interface for using the class) and implementation details that users
 don't need to know about.
 
-Classes are built from a specification that declares the interface of the class (i.e. what commands minions of the classs respond to),
+Classes are built from a specification that declares the interface of the class (i.e. what commands instances of the classs respond to),
 as well as a package that provide the implementation of these commands.
 
 This separation of interface from implementation details is an important aspect of modular design, as it enables modules to be interchangeable (so long as they have the same interface).
@@ -661,15 +689,18 @@ and "OOP to me means only messaging, local retention and protection and hiding o
 =head1 RATIONALE
 
 Due to Perl's "assembly required" approach to OOP, there are many CPAN modules that exist to automate this assembly,
-perhaps the most popular being the L<Moose> family. Moo(se) is very effective at simplifying class building but this is typically achieved at the
-expense of L<Encapsulation|https://en.wikipedia.org/wiki/Information_hiding> (the hiding of implementation details from end users).
+perhaps the most popular being the L<Moose> family. Although Moo(se) is very effective at simplifying class building, this is typically achieved at the
+expense of L<Encapsulation|https://en.wikipedia.org/wiki/Information_hiding> (because Moose encourages the exposure of all an object's attributes via methods), and this in turn encourages
+designs that are tightly L<coupled|https://en.wikipedia.org/wiki/Coupling_(computer_programming)>.
 
-To see this first hand, try writing the fixed size queue from L<Minions::Implementation/OBJECT COMPOSITION> using L<Moo>, bearing in mind that the only operations the queue should allow are C<push>, C<pop> and C<size>. It is also a revealing exercise to consider how this queue would be written in Ruby or PHP (e.g. would you need to expose all object attributes via methods?). 
+To see this first hand, try writing the fixed size queue from L<Minions::Implementation/OBJECT COMPOSITION> using L<Moo>, bearing in mind that the only operations the queue should allow are C<push>, C<pop> and C<size>. It is also a revealing exercise to consider how this queue would be written in another language such as Ruby or PHP (e.g. would you need to expose all object attributes via methods?). 
 
-Minions takes inspriation from Moose's declaratve approach to simplifying OO automation, but does not require or encourage encapsulation to be sacrificed.
+Minions takes inspriation from Moose's declaratve approach to simplifying OO automation, but also aims to put encapsulation and loose coupling on the path of least resistance.
 
 =head2 The Tale of Minions
 
+The following fable illustrates the main ideas of OOP.
+
 There once was a farmer who had a flock of sheep. His typical workday looked like:
 
     $farmer->move_flock($pasture)
@@ -696,7 +727,34 @@ This did give the farmer more time for C<other_important_work()>, but unfornatel
 
 C<$sheep_dog> was more reliable and demanded less pay than C<$shepherd_boy>, so this was a win for the farmer.
 
-Object Oriented design is essentially the act of minionization, i.e. deciding which minions ($objects) will do what work, and how to communicate with them (using an interface).
+=head3 Ideas
+
+Object Oriented design is essentially the act of minionization, i.e. deciding which minions (objects) will do what work, and how to communicate with them (using an interface).
+
+The most important ideas are
+
+=head4 Delegation
+
+To handle complexity, delegate to a suitable entity e.g. the farmer delegates some of his work to C<$shepherd_boy> (and later on to C<$sheep_dog>).
+
+=head4 Encapsulation
+
+We tell objects what to do, rather than micro-manage e.g.
+
+    $sheep_dog->monitor_flock();
+
+rather than
+
+    $sheep_dog->{brain}{task}{monitor_flock} = 1;
+
+At a high level, we do not particularly care what the internals of the object are. We only care what the object can do.
+
+But, an object becomes harder to change the more its internals are exposed.
+
+=head4 Polymorphism
+
+C<$sheep_dog> and C<$shepherd_boy> both understood the same commands, so replacing the latter with the former was easier than it would have been otherwise.
+
 
 =head1 USAGE
 
@@ -762,6 +820,9 @@ The class defined in the SYNOPSIS could also be defined like this
     is $counter->next => 0;
     is $counter->next => 1;
 
+I<This example was included for completeness. Creating a class this way is not recommended for real world
+projects as it doesn't scale up as well as the mainstream usage (i.e. using separate packages).>
+
 =head2 Specification
 
 The meaning of the keys in the specification hash are described next.
@@ -829,6 +890,10 @@ Also note that for any class C<Foo> created using Minions, and for any object cr
 Please report any bugs or feature requests via the GitHub web interface at
 L<https://github.com/arunbear/minions/issues>.
 
+=head1 ACKNOWLEDGEMENTS
+
+Stevan Little (for creating Moose), Tye McQueen (for numerous insights on class building and modular programming).
+
 =head1 AUTHOR
 
 Arun Prasaad E<lt>arunbear@cpan.orgE<gt>
