@@ -2,24 +2,25 @@ package Example::Roles::Acme::Queue_v1;
 
 use Minions::Implementation
     has  => {
-        q => { default => sub { [ ] } },
+        items => { default => sub { [ ] } },
     }, 
 ;
 
 sub size {
     my ($self) = @_;
-    scalar @{ $self->{$__q} };
+    scalar @{ $self->{$__items} };
 }
 
 sub push {
     my ($self, $val) = @_;
 
-    push @{ $self->{$__q} }, $val;
+    push @{ $self->{$__items} }, $val;
 }
 
 sub pop {
     my ($self) = @_;
-    shift @{ $self->{$__q} };
+
+    shift @{ $self->{$__items} };
 }
 
 1;
